<?php
/***************************************************************************
 *
 *   MOD                  : Atlas MOD
 *   file                 : includes/gmap_functions.php
 *   copyright            : (C) 2005 Jonas Neubert
 *   web                  : www.jonemo.de
 *
 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/
// Calculates the distance between two points (that will be users in most cases)
function calculate_distance ($long1, $lat1, $long2, $lat2)
{
	if ($long1 == $long2 && $lat1 == $lat2) return 0;

	if ($long1 == 0)	return 0;
	else	$long1 = deg2rad($long1);

	if ($long2 == 0)	return 0;
	else	$long2 = deg2rad($long2);

	if ($lat1 == 0)	return 0;
	else	$lat1 = deg2rad($lat1);

	if ($lat2 == 0)	return 0;
	else	$lat2 = deg2rad($lat2);

	$x = pow( sin(($lat2 - $lat1) / 2), 2) + cos($lat1) * cos($lat2) * pow(sin(($long2 - $long1) / 2), 2);
	return atan2(sqrt($x), sqrt(1 - $x)) * 2 * 6378.137;	// 6378.137 is the radius of the earth
}

// converts kilometers to miles
function to_miles ($dist)
{
	return intval($dist / 1.609344) . ' mi';
}

// converts kilometers to kilometers - sounds stupid but isn't, as the distance from the source function is non-integer
function to_kilometer ($dist)
{
	return intval($dist) . ' km';
}




function make_atlasmod_js ($modus, $start_long, $start_lat, $start_zoom_level, $limits, $distance_parameters)
{
	global $template, $board_config, $lang, $phpbb_root_path, $nav_links, $gen_simple_header;
	global $userdata, $user_ip, $session_length;


	$template->set_filenames(array(
		'atlasjs' => 'atlas_js.tpl')
	);
	
	$template->assign_vars(array(
		// urls
		'U_PROFILE_G' => append_sid('profile.php?mode=viewprofile'),
		'U_XML_ADRESS' => append_sid($phpbb_root_path . 'atlas.php?mode=xml'),
		'U_PATH_TO_ATLAS_LIB_JS' => $phpbb_root_path . 'includes/atlaslib.js',
		
		// the users own values
		'LONGITUDE' => $userdata['user_long'],
		'LATITUDE' => $userdata['user_lat'],
		
		'MODUS' => $modus,
		'GOOGLE_API_KEY' => (defined('IN_ADMIN')) ? $board_config['atlas_google_api_key_admin'] : $board_config['atlas_google_api_key'],

		// initial settings
		'START_MAP_TYPE' => $board_config['atlas_start_map_type'],
		'START_LONG' => $start_long,	// given as function parameter
		'START_LAT' => $start_lat,		// given as function parameter
		'START_ZOOM_LEVEL' => ( empty($start_zoom_level) ) ? $board_config['atlas_start_zoom'] : $start_zoom_level,	// given as function parameter
		'START_MIN_LONG' => $limits['min_long'],	// given as function parameter
		'START_MAX_LONG' => $limits['max_long'],
		'START_MIN_LAT' => $limits['min_lat'],
		'START_MAX_LAT' => $limits['max_lat'],
		'CONTROL_GLMC' => $board_config['atlas_control_glmc'],
		'CONTROL_GSMC' => $board_config['atlas_control_gsmc'],
		'CONTROL_GSZC' => $board_config['atlas_control_gszc'],
		'CONTROL_GMTC' => $board_config['atlas_control_gmtc'],

		'L_CHOOSE_THIS' => $lang['GMap_set_this_location'],
		'L_YOUR_LOCATION' => $lang['GMap_your_location'],
		'L_GMAP_NOT_COMPATIBLE' => $lang['GMap_not_compatible'],
		'L_CALLED_OFFLINE' => $lang['GMap_called_offline'],
		'L_LONGITUDE' => $lang['GMap_longitude'],
		'L_LATITUDE' => $lang['GMap_latitude'],
		'L_USERNAME' => $lang['Username'],
		'L_DISTANCE' => $lang['GMap_distance'],
		'GEOCODER_NOT_FOUND' => $lang['Atlas_not_found'],
	));

	if ($modus == 2)	// if a distance is to be shown
	{
		$template->assign_vars(array(
			'PID' => $distance_parameters['pid'],
			'P_USERNAME' => $distance_parameters['username'],
			'P_LONGITUDE' => $distance_parameters['lon'],
			'P_LATITUDE' => $distance_parameters['lat'],
		));
	}
	
	if ($modus != 3) // find coordinates
	{
		$template->assign_vars(array(
			'GEOCODER_START' => "<!--",
			'GEOCODER_END' => "-->",
		));
	}

	$template->assign_var_from_handle('ATLAS_MOD_JS', 'atlasjs');
}

?>
